@@ -75,7 +75,6 @@ static std::string read_gz_file(const char* test_id, const char* suffix) {
     return input;
 }
 
-// cppcheck-suppress passedByValue
 static header_buffer_type parse_xml(std::string input) {
     osmium::thread::Pool pool;
     osmium::io::detail::future_string_queue_type input_queue;
@@ -92,7 +91,8 @@ static header_buffer_type parse_xml(std::string input) {
         output_queue,
         header_promise,
         osmium::osm_entity_bits::all,
-        osmium::io::read_meta::yes
+        osmium::io::read_meta::yes,
+        osmium::io::buffers_type::any
     };
     osmium::io::detail::XMLParser parser{args};
     parser.parse();
